@@ -20,10 +20,10 @@
  *
  * CVS Information:
  * 
- * $Source: /home/globdev/CVS/globus-packages/gram/jobmanager/source/globus_gram_job_manager_config.c,v $
- * $Date: 2012/08/17 14:37:15 $
- * $Revision: 1.24.4.4 $
- * $Author: bester $
+ * $Source$
+ * $Date$
+ * $Revision$
+ * $Author$
  */
 
 #include "globus_gram_job_manager.h"
@@ -342,11 +342,12 @@ globus_gram_job_manager_config_init(
         else if ((strcmp(argv[i], "-globus-job-dir") == 0)
                  && (i + 1 < argc))
         {
+            char * tmp_user_name = getenv("LOGNAME");
 	    config->job_dir_home =
                 globus_common_create_string(
                     "%s/%s",
                     argv[++i],
-                    strdup(getenv("USER")));
+                    tmp_user_name ? tmp_user_name : "USER");
 
             if (config->job_dir_home == NULL)
             {
