@@ -20,10 +20,10 @@
  *
  * CVS Information:
  * 
- * $Source: /home/globdev/CVS/globus-packages/gram/jobmanager/source/globus_gram_job_manager_state.c,v $
- * $Date: 2012/05/16 19:24:41 $
- * $Revision: 1.55.2.7 $
- * $Author: bester $
+ * $Source$
+ * $Date$
+ * $Revision$
+ * $Author$
  */
 #include "globus_gram_job_manager.h"
 #include "globus_rsl_assist.h"
@@ -1256,7 +1256,7 @@ globus_gram_job_manager_reply(
          * No response context, the gatekeeper will supply HTTP response line,
          * so we skip the first line of the framed reply
          */
-        reply = strstr(sendbuf, "\r\n");
+        reply = (globus_byte_t *) strstr((char *) sendbuf, "\r\n");
 
         reply += 2;
         sendsize -= (reply - sendbuf);
