@@ -21,10 +21,10 @@
  * RSL Validation Support for the GRAM Job Manager.
  *
  * CVS Information:
- * $Source: /home/globdev/CVS/globus-packages/gram/jobmanager/source/globus_gram_job_manager_validate.c,v $
- * $Date: 2012/03/26 18:05:07 $
- * $Revision: 1.18.8.3 $
- * $Author: bester $
+ * $Source$
+ * $Date$
+ * $Revision$
+ * $Author$
  */
 
 #define GLOBUS_GRAM_VALIDATE_JOB_SUBMIT_STRING \
@@ -247,6 +247,13 @@ globus_gram_job_manager_validation_update(
             do_update = GLOBUS_TRUE;
         }
     }
+    if (! (manager->validation_file_exists[0] ||
+           manager->validation_file_exists[1] ||
+           manager->validation_file_exists[2] ||
+           manager->validation_file_exists[3]) )
+    {
+        do_update = 1;
+    }
 
     if (do_update)
     {
@@ -302,11 +309,22 @@ globus_gram_job_manager_validation_init(
         &manager->validation_records,
         &manager->gt3_failure_message);
 
+    if(rc != GLOBUS_SUCCESS)
+    {
+        manager->validation_file_exists[0] = GLOBUS_FALSE;
+        rc = globus_rvf_parse_string(
+                globus_i_gram_default_rvf, 
+                &manager->validation_records,
+                &manager->gt3_failure_message);
+    }
+    else
+    {
+        manager->validation_file_exists[0] = GLOBUS_TRUE;
+    }
     if(rc != GLOBUS_SUCCESS)
     {
         goto read_validation_failed;
     }
-    manager->validation_file_exists[0] = GLOBUS_TRUE;
 
     if(access(lrm_validation_filename, R_OK) == 0)
     {
